SpamBayes - Interface utilisateur

SpamBayes - Interface utilisateur: Accueil > ui.html

#### Introduction

Cette page, `ui.html`, définit l'aspect visuel de l'interface utilisateur du serveur SpamBayes. Les différentes parties de code HTML définies ici sont extraites et générées à l'exécution pour produire du code HTML dynamique que le serveur SpamBayes va servir - ce fichier est un ensemble de de composants HTML. `PyMeldLite` est le fantastique module qui fournit la correspondance entre les objets et le code HTML. Chaque partie de code HTML à réécrire est signalé par des balises du type `id`, et devient un objet Python pendant la phase d'exécution.

Cette "Introduction" est une présentation de ce fichier. Elle n'a pas besoin d'être traduite et n'est jamais utilisée dans l'interface homme-machine.

Voici un exemple du mode de fonctionnement : une boîte de dialogue avec un `id` de `examplebox`: PyMeldLite vous permet de manipuler le code HTML par programmation :

        >>> import PyMeldLite
        >>> html = open("ui.html", "rt").read()
        >>> doc = PyMeldLite.Container(html)
        >>> print doc.examplebox
        <input id="examplebox" size="10" type="text" value="exemple"/>
        >>> doc.examplebox.value = "Changé"
        >>> print doc.examplebox
        <input id="examplebox" size="10" type="text" value="Changé"/>

Le code Python nécessaire à la génération de l'interface utilisateur HTML n'a pas besoin de s'embêter à concaténer des chaînes ou construire des composants HTML de zéro dans le code. L'aspect visuel est dénini uniquement par ce fichier HTML - changement de feuille de style, traduction (autres langues), ajout d'une extension à l'interface utilisateur - et tout cela très simplement.

Les composants de l'interface utilisateur figurent ci-dessous avec leurs `id`s.

headedBox

Headed box
| Ceci est le "headedBox". La plupart des éléments de l'interface utilisateur est présentée dans des boîtes comme celle-ci. Les élements ne sont pas présentés ici `ui.html` pour éviter une duplication de code HTML. Telle quelle, cette section n'a pas besoin d'être traduite.

Aide

SpamBayes - Aide
| Navré, pas d'aide disponible pour cette section.
Si vous pensez avoir découvert un bogue (bug) dans SpamBayes, ou que vous êtes perdu dans la manière de procéder (installation / mise en oeuvre, ...), vous pouvez vous adresser à la mailing list pour obtenir de l'aide. Veuillez noter que les membres de cette liste sont des volontaires qui répondent sur leur temps libre. Une réponse à vos questions peut prendre un certain temps. Si vous étiez quasiment sûr d'avoir trouvé un bogue, le mieux est de le soumettre via le Suivi SourceForge, ceci évitera d'éventuelles pertes de messages dans la possible masse de messages adressés à la liste et palier aux désagrément occasionnés par des virus qui peuvent remplir la boîte de messagerie. Lors de la soumission d'un message, merci d'être aussi précis que possible pour éviter des échanges inutiles tels que "merci de nous indiquer ceci ou cela". Il est de bonne augure d'inclure le mode opératoire nous permettant de reproduire le problème, le contenu des messages complet ayant provoqué le boque, une copie du message, ... ainsi que votre suggestion. Toute suggestion de traduction est également la bienvenue. Pour vous aider, SpamBayes peut créer un message de demande d'assistance pour vous.

Aide - Résumé des fonctionnalités

##### Résumé des fonctionnalités

Lorsque vous commencez à utiliser SpamBayes, tous vos mails seront considérés comme 'Douteux' car SpamBayes n'a aucun moyen de reconnaître ce qui pour vous constitue un bon ou un mauvais message. Il va donc être nécessaire de lui apprendre à reconnaître les messages. Au fur et à mesure, de moins en moins de messages seront considérés comme douteux et il ne restera plus que deux catégories de messages, les bons et les mauvais. Rien que lui montrer une vingtaine d'exemple de chaque est suffisant pour obtenir de bons résultats. A un certain stades, vous constaterez même que certains messages envoyés automatiquement par des virus par exemple sont aiguillés vers le dossier réservé aux messages non sollicités.

SpamBayes conserve une copie temporaire de tous vos messages entrants, pour que vous soyez en mesure d'utiliser n'importe quel client de messagerie. Pour chacun de ces messages, vous indiquerez à SpamBayes comment il convient de le considérer. La page affiche la liste des messages qui sont arrivés les %(cache_expiry_days) derniers jours et pour lesquels vous n'avez pas établi de classification. Pour chaque message, vous devez choisir soit de l'ignorer (pas d'apprentissage sur ce message), d'attendre (garder le message pour un apprentissage futur), ou l'utiliser pour entraîner SpamBayes (soit en tant que bon message - bon (ham), ou mauvais - spam). Pour cela, il suffit de simplement cliquer sur le cercle idoine. Pour aller plus vite, vous pouvez aussi cliquer sur le titre de la colonne pour classifier tous les messages d'un seul coup.

Pour vous aider à déterminer la nature du message, le sujet ainsi que l'emetteur du message vous sont présentés. Bien évidemment, ces informations n'étant pas toujours suffisantes pour prendre votre décision, vous pouvez également en visualiser le contenu (en texte brut par sécurité pour éviter qu'un virus n'endommage votre système) en cliquant sur le sujet du message.

Une fois les actions choisies sur chacun des messages, il vous suffit de cliquer sur le bouton Apprentissage figurant en bas de page. SpamBayes mettra alors à jour sa base de donnée pour intégrer votre classification et en tiendra compte sur vos prochains messages.

SpamBayes effectue cette classification sur vos nouveaux messages en fonction de vos choix précédents. Si elle est correcte, vous pourrez choisir d'ignorer le message - c.f. le wiki SpamBayes pour une discussion sur les techniques d'apprentissage (en anglais). Vous pouvez également consulter les éléments (Tokens) contenus dans le message (pas uniquement les mots mais aussi d'autres éléments générés par SpamBayes) et les indices (Clues) utilisés par SpamBayes pour classifier le message (notez que tous les les éléments du messages ne sont pas utilisés pour la classification).

Pour des soucis de visibilité, les nouveaux messages en attente de cette classification sont groupés par leur date d'arrivée. Des boutons Jour précédent et Jour suivant sont à votre disposition en haut de page pour changer de jour. Si un nouveau message arrive pendant que vous effectuez la classification, il ne sera pas automatiquement ajouté à la liste affichée à l'écran ; il vous faudra cliquer sur le bouton Raffraîchir en haut de page pour le voir apparaître.

##### Aide - Statistiques

SpamBayes conserve certaines informations sur la classification des messages. Cette page permet d'afficher les statistiques sur la classification des messages et l'état actuel de l'apprentissage.

Au jour d'aujourd'hui, la page affiche le nombre de messages considérés comme bon, mauvais (spam) ou douteux, le nombre de faux négatifs et faux positifs et enfin combien de messages ont été considérés comme douteux (et comment vous les avez classifié).

Notez que les données de cette page figurent dans la base de données "message info" utilisée par SpamBayes depuis la dernière création de la base (vous pouvez recréer la base sur demande).

##### Aide - Page principale

Ceci est la page principale d'aide sur l'interface Web de SpamBayes. Vous y trouverez l'état actuel de SpamBayes ainsi que les liens vous permettant d'accéder à vos messages ou de modifier votre configuration.

Cette page vous permet également de pratiquer l'apprentissage initial soit à partir de messages stockés dans des fichiers mbox (Unix) ou dbx (Outlook Express), soit à partir d'un message que vous fournissez. Cliquez sur le bouton "Parcourir..." (ou collez le texte, en incluant les en-têtes), et cliquez sur le bouton approprié, soit Ceci est un bon message soit Ceci est du Spam

De même, si vous avez un message que vous souhaitez soumettre pour analyse, vous avez une fenêtre à votre disposition. Deux solutions s'offrent à vous, un copier/coller ou "Importer..." le message. Il suffira alors de cliquer sur le bouton Analyser et une page affichant comment SpamBayes a classifié le message s'affichera.

Pour obtenir des informations sur un mot dans la base de données dédiée aux statistiques (qui est le coeur de SpamBayes), vous pouvez utiliser le champ "Mot à analyser". Entrez alors simplement le mot à rechercher et cliquez sur le bouton Analyser ce mot. La recherche avancée vous permet d'aller plus loin car elle admet les caratères génériques et le expressions régulières.

Vous avez également la possibilité d'obtenir des informations sur un message en partculier grâce à la copie temporaire que le système conserve avant de vous les délivrer. Ceci peut être intéressant si vous avez fait une erreur sur la classification d'un message et voulez repratiquer l'analyse. La recherche est poissible sur l'ensemble du message, que ce soit sur le sujet, les en-têtes, le corps du message ou encore les identifiants (ID) SpamBayes. Les messages correspondants sont affichées dans l'interface traditionnelle. Attention cependant, les messages qui ont expiré (les messages ont une durée de vie de %(cache_expiry_days) jours) ne peuvent plus être trouvés.

Demande pré-remplie d'aide / soumission de bogue

Send Help Message
Emetteur : |
Sujet : |
Message : |
Fichier de trace à joindre : |

Status

Le mandataire (proxy) POP3 est en écoute sur le port 1110, et relaie les données du serveur d'origine POP3 example.com. Connexions POP3 en cours : 0. Total de connexions POP3 pour cette session : 0. Répartition des messages analysés durant cette sessions : Spam : 0, Bons : 0, Douteux : 0. Répartition des messages utilisés pour l'apprentissage : Spam : 0 Bons : 0 Statistiques complémentaires... |  | Vous pouvez configurer SpamBayes à partir de la page de paramétrage.
Attention : mettez votre message d'alerte ici ! Ces alertes sont insérées dynamiquement, la traduction n'est de fait pas nécessaire.

reviewText

Le proxy SpamBayes stocke tous les messages qu'il voit. Vous pouvez utiliser l'apprentissage sur ces messages à partir de la page de Classification des messages.

reviewTable

Ici sont représentés les messages que vous pouvez utiliser pour l'apprentissage. Appuyez sur le bouton approprié pour chaque message et clqiuer sur le bouton 'Apprentissage' ci-dessous. 'Mettre en attente' conserve le message ici pour remettre l'opération à plus tard. Vous pouvez également cliquer sur l'en-tête de colonne Annuler / Mettre en attente / Bon / Spam pour traiter tous les messages d'un coup. L'autre en-tête vous permet de trier les messages par type (attention, vous perdriez alors toute modification non validée faite sur la page).

Messages reconnus comme étant du TYPE :
Emetteur | Sujet du message | Reception le | Annuler / En attente / Bon / Spam | Score
Richie Hindle <richie@entrian.com> | Re: SpamBayes et PyMeld c'est génial ! 8-) | Sat, 11 Sep 2003 19:03:11 |  | 0.00% | Indices | Eléments

Import

Vous pouvez importer un message , mbox (unix) ou dbx :
ou coller tout un message (en incluant les en-têtes) ici :

(Le formulaire d'import est utilisé aussi bien pour l'apprentissage que pour la classification - les éléments inutiles seront supprimés à l'exécution)

Recherche d'un mot

| Requête simple Requête avec caractères génériques (*, ?) Requête à partir d'expressions régulières Ignorer la casse Nombre maximal de messages

Recherche d'un message

Chercher dans... Identificateur SpamBayes Sujet En-tête de message Corps du message | Ignorer la casse Nombre maximal de messages |

Statistiques d'un mot

Nombre de messages de type spam : 123.
Nombre de bons messages : 456.
Probabilité qu'un message contenant ce mot soit un spam : 0.789.

Mot | # Spam | # Bon | Probabilé
spambayes | 123 | 436 | .789

Résultat de classification

Probabilité de spam (après) : 0.123. Probabilité de spam (avant) : 0.125.

Voici la table des indices menant à cette probabilité

Mot | Probabilé | Occurences dans un bon message | Occurences dans un spam
Mot exemple | 0.123 | 1 | 2

Retour à lapage principale ou classification d'un autre

(La feuille de classification est ici)

Formulaire de paramétrage

Cette page vous permet de changer le comportement de SpamBayes relatif au traitement de vos messages. Vos choix sont stockés dans /chemin/exemple.

Element: |  |  | (Réservé à l'aide)
Element: | Valeur de l'élément |  | (Réservé à l'aide)
Valeur actuelle : | (valeur)
Valeur actuelle : | (valeur)
Nom du dossier / répertoire | (Réservé à l'aide)

Vous quittez le système

Terminé. Merci, à bientôt.

Version 0.00 Interface Web de SpamBayes, Lun 30 Dec 14:04:32 2002. Spambayes.org | Help |